==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a virtual machines network configuration's DNS settings.
 * @property dnsServers List of DNS servers IP addresses
 */
public data class VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs(
    public val dnsServers: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs].
 */
@PulumiTagMarker
public class VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgsBuilder internal
constructor() {
    private var dnsServers: Output<List<String>>? = null

    /**
     * @param value List of DNS servers IP addresses
     */
    @JvmName("mkgspemkbhcngfcs")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("wisljwrsdxmfaeut")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values List of DNS servers IP addresses
     */
    @JvmName("lfnlfvselvsmuglj")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value List of DNS servers IP addresses
     */
    @JvmName("hqqlnyfgbxkqhdas")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values List of DNS servers IP addresses
     */
    @JvmName("beiedsvdjduthfpw")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    internal fun build(): VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs =
        VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs(
            dnsServers = dnsServers,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a virtual machines network configuration's DNS settings.
 * @property dnsServers List of DNS servers IP addresses
 */
public data class VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs(
    public val dnsServers: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs].
 */
@PulumiTagMarker
public class VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgsBuilder internal
constructor() {
    private var dnsServers: Output<List<String>>? = null

    /**
     * @param value List of DNS servers IP addresses
     */
    @JvmName("sbyuelqidnmdognt")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("owbabolkhuadlojh")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values List of DNS servers IP addresses
     */
    @JvmName("uyniaundgdjrthtn")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value List of DNS servers IP addresses
     */
    @JvmName("fovctrlxdnobcaia")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values List of DNS servers IP addresses
     */
    @JvmName("ybhdopewaxfyyarn")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    internal fun build(): VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs =
        VirtualMachineNetworkInterfaceDnsSettingsConfigurationArgs(
            dnsServers = dnsServers,
        )
}
